@@ -1,11 +1,14 @@
-__version__ = "1.0.0"
+__version__ = "1.3.0"
 
 from .client import (
     AIONutClient,
     NutCommandError,
     NUTError,
     NutLoginError,
+    NutOSSError,
     NUTProtocolError,
+    NutTimeoutError,
+    NutValueError,
 )
 
 __all__ = [
@@ -14,4 +17,7 @@ __all__ = [
     "NUTProtocolError",
     "NutLoginError",
     "NutCommandError",
+    "NutOSSError",
+    "NutTimeoutError",
+    "NutValueError",
 ]
